@@ -21,5 +21,26 @@ def create_profile(sender, instance, created, **kwargs):
     """
     profile_model = get_profile_model()
     if profile_model:
-        if created: 
-            p, c = profile_model.objects.get_or_create(user=instance)
+        if created:
+            try:
+                p, c = profile_model.objects.get_or_create(user=instance)
+            except:
+                pass
+
+def delete_profile(sender, instance, **kwargs):
+    """
+    Delete a matching profile whenever a user object is deleted.
+    if settings.USER_PROFILE_AUTO_DELETE is not defined or False, 
+    the auto profile creation is skipped
+    """
+    profile_model = get_profile_model()
+    if profile_model:
+        try:
+            profile_model.objects.get(user=instance).delete()
+        except:
+            pass
+
+
+
+
+
